==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/dd/db4/structEconomySettings.js <==
var structEconomySettings =
[
    [ "allow_shares", "dd/db4/structEconomySettings.html#a5ea775fd68e8be7b66537e033009c875", null ],
    [ "allow_town_level_crossings", "dd/db4/structEconomySettings.html#a98235e95f806552a849d641dbb5b905a", null ],
    [ "allow_town_roads", "dd/db4/structEconomySettings.html#aa80b60c4f666debcb5b7a11a17e1f828", null ],
    [ "bribe", "dd/db4/structEconomySettings.html#a021249346d7881d8f2bc6dc8925b374d", null ],
    [ "dist_local_authority", "dd/db4/structEconomySettings.html#ae8200ebf43d270414da57bd8fffc6e5c", null ],
    [ "exclusive_rights", "dd/db4/structEconomySettings.html#a2a250979ccd897ffaa264f094e98fbcd", null ],
    [ "feeder_payment_share", "dd/db4/structEconomySettings.html#aac4bf0e5b262b521b84555fca0938524", null ],
    [ "found_town", "dd/db4/structEconomySettings.html#a841e16a07a9e1f593d688529aa8edc0b", null ],
    [ "fund_buildings", "dd/db4/structEconomySettings.html#aaae2b0477248ba6cf789e1a9d705ea83", null ],
    [ "fund_roads", "dd/db4/structEconomySettings.html#ab1b237407a863a879dbfa975a740101b", null ],
    [ "give_money", "dd/db4/structEconomySettings.html#ad0f1828f70f2b647de5971605ddde210", null ],
    [ "inflation", "dd/db4/structEconomySettings.html#a0e8f71c51dd512cb6c403ee458dff3b4", null ],
    [ "infrastructure_maintenance", "dd/db4/structEconomySettings.html#aad3e008336e6d0978d8c511e9f459669", null ],
    [ "initial_city_size", "dd/db4/structEconomySettings.html#af86caad4904a8755f51c3e2f7937bda0", null ],
    [ "larger_towns", "dd/db4/structEconomySettings.html#a95320f22cb293242d1596d450a86d0d6", null ],
    [ "mod_road_rebuild", "dd/db4/structEconomySettings.html#a2b07b7e6a6c90282193de89d53876158", null ],
    [ "multiple_industry_per_town", "dd/db4/structEconomySettings.html#ab17ae11cb15ee1618796cf7d62ebe052", null ],
    [ "smooth_economy", "dd/db4/structEconomySettings.html#a9d59a1127377cf5427a234f7d3400f68", null ],
    [ "station_noise_level", "dd/db4/structEconomySettings.html#aa8a63c7722d8399acecb5ea7e1c2ecae", null ],
    [ "town_growth_rate", "dd/db4/structEconomySettings.html#a965f43d19f27fd18b23cc541da2282ec", null ],
    [ "town_layout", "dd/db4/structEconomySettings.html#a3d024b90a951ab05223e0a0388e9b796", null ],
    [ "town_noise_population", "dd/db4/structEconomySettings.html#a08b0d1a09bba8ecb9bdb038b9a6adb44", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/dd/db4/structEconomySettings.js <==
var structEconomySettings =
[
    [ "allow_shares", "dd/db4/structEconomySettings.html#a5ea775fd68e8be7b66537e033009c875", null ],
    [ "allow_town_level_crossings", "dd/db4/structEconomySettings.html#a98235e95f806552a849d641dbb5b905a", null ],
    [ "allow_town_roads", "dd/db4/structEconomySettings.html#aa80b60c4f666debcb5b7a11a17e1f828", null ],
    [ "bribe", "dd/db4/structEconomySettings.html#a021249346d7881d8f2bc6dc8925b374d", null ],
    [ "dist_local_authority", "dd/db4/structEconomySettings.html#ae8200ebf43d270414da57bd8fffc6e5c", null ],
    [ "exclusive_rights", "dd/db4/structEconomySettings.html#a2a250979ccd897ffaa264f094e98fbcd", null ],
    [ "feeder_payment_share", "dd/db4/structEconomySettings.html#aac4bf0e5b262b521b84555fca0938524", null ],
    [ "found_town", "dd/db4/structEconomySettings.html#a0efadc85d115a09d951998773736a873", null ],
    [ "fund_buildings", "dd/db4/structEconomySettings.html#aaae2b0477248ba6cf789e1a9d705ea83", null ],
    [ "fund_roads", "dd/db4/structEconomySettings.html#ab1b237407a863a879dbfa975a740101b", null ],
    [ "give_money", "dd/db4/structEconomySettings.html#ad0f1828f70f2b647de5971605ddde210", null ],
    [ "inflation", "dd/db4/structEconomySettings.html#a0e8f71c51dd512cb6c403ee458dff3b4", null ],
    [ "infrastructure_maintenance", "dd/db4/structEconomySettings.html#aad3e008336e6d0978d8c511e9f459669", null ],
    [ "initial_city_size", "dd/db4/structEconomySettings.html#af86caad4904a8755f51c3e2f7937bda0", null ],
    [ "larger_towns", "dd/db4/structEconomySettings.html#a95320f22cb293242d1596d450a86d0d6", null ],
    [ "min_years_for_shares", "dd/db4/structEconomySettings.html#aad0e9a417835b207c446dadf8181f704", null ],
    [ "mod_road_rebuild", "dd/db4/structEconomySettings.html#a2b07b7e6a6c90282193de89d53876158", null ],
    [ "multiple_industry_per_town", "dd/db4/structEconomySettings.html#ab17ae11cb15ee1618796cf7d62ebe052", null ],
    [ "station_noise_level", "dd/db4/structEconomySettings.html#aa8a63c7722d8399acecb5ea7e1c2ecae", null ],
    [ "town_cargogen_mode", "dd/db4/structEconomySettings.html#ae2346acba51e02d9134ed053fd79c526", null ],
    [ "town_growth_rate", "dd/db4/structEconomySettings.html#a965f43d19f27fd18b23cc541da2282ec", null ],
    [ "town_layout", "dd/db4/structEconomySettings.html#a6ec0491fbada5843902da94ae38e2b9d", null ],
    [ "town_noise_population", "dd/db4/structEconomySettings.html#a08b0d1a09bba8ecb9bdb038b9a6adb44", null ],
    [ "type", "dd/db4/structEconomySettings.html#a3b4ada6702c4222ef7d253834907d614", null ]
];
